@@ -4,11 +4,14 @@
 #' \bold{Warning:} This function may be moved to a new package.
 #'
 #' @import highcharter
+#' @importFrom tibble add_column
 #' @export
 #'
 #' @param df data frame like the value of a \code{\link{frequencyQuery}}
 #' @param as.alternatives boolean decides whether queries should be treated as mutually exclusive and exhaustive wrt. to some meaningful class (e.g. spelling variants of a certain word form).
 #' @param ylabel defaults to \% if \code{as.alternatives} is \code{true} and to "ipm" otherwise.
+#' @param smooth boolean decides whether the graph is smoothed using the highcharts plot types spline and areasplinerange.
+#' @param ... additional arguments passed to \code{\link{hc_add_series}}
 #'
 #' @examples
 #' \donttest{year <- c(1990:2018)}\dontshow{year <- c(2013:2013)}
@@ -33,13 +36,16 @@
 #'   hc_freq_by_year_ci()
 #' }
 #'
-hc_freq_by_year_ci <- function(df, as.alternatives = FALSE, ylabel = if(as.alternatives) "%" else "ipm") {
+hc_freq_by_year_ci <- function(df, as.alternatives = FALSE,
+                               ylabel = if(as.alternatives) "%" else "ipm",
+                               smooth = FALSE,
+                               ...) {
   title <- ""
   df <- df %>%
     { if(! as.alternatives) ipm(.) else RKorAPClient::percent(.) }
 
   if (!"year" %in% colnames(df)) {
-    df <- df %>% mutate(year = as.integer(queryStringToLabel(df$vc, pubDateOnly = TRUE)))
+    df <- df %>% add_column(year = as.integer(queryStringToLabel(df$vc, pubDateOnly = TRUE)))
   }
   if (!"condition" %in% colnames(df)) {
     if (length(base::unique(df$query)) > 1) {
@@ -51,7 +57,7 @@ hc_freq_by_year_ci <- function(df, as.alternatives = FALSE, ylabel = if(as.alter
     } else {
       if (length(base::unique(queryStringToLabel(df$vc, excludePubDate = TRUE ))) > 1) {
         title <- base::unique(df$query)
-        df <- df %>% mutate(condition = queryStringToLabel(vc, excludePubDate = TRUE ))
+        df <- df %>% add_column(condition = queryStringToLabel(vc, excludePubDate = TRUE ))
       } else {
         df <- df %>% mutate(condition = query)
       }
@@ -61,7 +67,6 @@ hc_freq_by_year_ci <- function(df, as.alternatives = FALSE, ylabel = if(as.alter
   palette <- c("#1F77B4", "#FF7F0E", "#2CA02C", "#D62728", "#9467BD", "#8C564B", "#E377C2", "#7F7F7F", "#BCBD22", "#17BECF", "#AEC7E8", "#FFBB78", "#98DF8A", "#FF9896", "#C5B0D5", "#C49C94", "#F7B6D2", "#C7C7C7", "#DBDB8D", "#9EDAE5")
   highcharter::highchart() %>%
     hc_title(text=title) %>%
-    hc_chart(zoomType="xy") %>%
     hc_yAxis(
       title = list(text = if (as.alternatives) "" else ylabel),
       ceiling = if (as.alternatives) 100 else NULL,
@@ -72,14 +77,18 @@ hc_freq_by_year_ci <- function(df, as.alternatives = FALSE, ylabel = if(as.alter
     hc_add_theme(hc_theme_google(colors=palette)) %>%
     hc_plotOptions(
       series = list(enabled = TRUE),
+      spline = list(cursor = 'pointer', point = list(events = list(
+        click = JS("function() { window.open(this.click, 'korap'); }")
+      ))),
       line = list(cursor = 'pointer', point = list(events = list(
         click = JS("function() { window.open(this.click, 'korap'); }")
       )))) %>%
     hc_credits(enabled = TRUE,
-               text = "KorAP R Client Pakckage",
-               href = "//github.com/KorAP/RKorAPClient/") %>%
+               text = "KorAP R Client Package",
+               href = "https://github.com/KorAP/RKorAPClient/") %>%
     hc_exporting(enabled = TRUE) %>%
     hc_tooltip(
+      headerFormat = '<span style="font-size: 10pt">{point.key}</span><br/>',
       formatter = JS(paste0("function (tooltip) {
         var str = tooltip.defaultFormatter.call(this, tooltip);
         if(Array.isArray(str))  {
@@ -95,14 +104,18 @@ hc_freq_by_year_ci <- function(df, as.alternatives = FALSE, ylabel = if(as.alter
       shared = TRUE,
       valueSuffix = paste0('\U2009', ylabel)
     ) %>%
-    hc_add_series_korap_frequencies(df, as.alternatives)
+    hc_add_series_korap_frequencies(df, smooth, as.alternatives, ...)
 }
 
 ## Mute notes: "no visible binding for global variable:"
 globalVariables(c("value", "query", "condition", "vc"))
 
-hc_add_series_korap_frequencies <- function(hc, df, as.alternatives = FALSE) {
+hc_add_series_korap_frequencies <- function(hc, df, smooth = FALSE,
+                                            as.alternatives = FALSE,
+                                            ...) {
   index <- 0
+  type <- ifelse(smooth, "spline", "line")
+  areatype <- ifelse(smooth, "areasplinerange", "arearange")
   for(q in unique(df$condition)) {
     dat <- df[df$condition==q,]
     hc <- hc %>% hc_add_series(
@@ -115,15 +128,16 @@ hc_add_series_korap_frequencies <- function(hc, df, as.alternatives = FALSE) {
         click = dat$webUIRequestUrl
       ),
       hcaes(year, value),
-      type = 'line',
+      type = type,
       colorIndex = index,
-      zIndex = 1
+      zIndex = 1,
+      ...
     ) %>%
       hc_add_series(
         name = "ci",
         data = dat[,c('year', 'conf.low', 'conf.high')],
         hcaes(x = year, low = conf.low, high = conf.high),
-        type = 'arearange',
+        type = areatype,
         fillOpacity = 0.3,
         lineWidth = 0,
         marker = list(enabled = FALSE),
@@ -136,3 +150,11 @@ hc_add_series_korap_frequencies <- function(hc, df, as.alternatives = FALSE) {
   }
   hc
 }
+
+.onAttach <- function(libname = find.package("RKorAPClient"),
+                      pkgname = "RKorAPClient") {
+  packageStartupMessage(
+    "If you intend to use the Highcharts plot options, please note that Highcharts (www.highcharts.com) is a Highsoft software product which is not free for commercial and governmental use."
+  )
+}
+
